Visualization
=============

The machado web interface requires the instalation and configuration of third party software.


.. toctree::
   :maxdepth: 2
   :titlesonly:

   Index and search <index_search>
   Web server <webserver>
   JBrowse <jbrowse>
   Cache <cache>
